==> CGFeedMaker-1.0.15.tar.gz: CGFeedMaker/lang/ext/nb_NO.php <==
<?php
$lang['addcategory'] = 'Legg til en ny kategori';
$lang['addedit_feed'] = 'Legg til/rediger levende bokmerke';
$lang['addfeed'] = 'Legg til nytt levende bokmerker';
$lang['areyousure_delete'] = 'Er du sikker p&aring; at du vil slette denne enheten?';
$lang['cancel'] = 'Avbryt';
$lang['categories'] = 'Kategorier';
$lang['current_value'] = 'N&aring;v&aelig;rende verdi';
$lang['delete'] = 'Slett';
$lang['details'] = 'Detaljer';
$lang['edit'] = 'Rediger';
$lang['error_missingparam'] = 'En p&aring;krevd parameter eller verdi ble ikke funnet';
$lang['error_nameexists'] = 'En enhet med det navnet eksisterer allerede';
$lang['error_nocatname'] = 'Vennligst spesifiser et kategorinavn';
$lang['error_nonamegiven'] = 'Du m&aring; oppgi et navn/alias';
$lang['error_nopermission'] = 'Tilgang nektet';
$lang['error_notemplate'] = 'Ingen mal oppgitt';
$lang['feeds'] = 'Levende bokmerker';
$lang['feed_copyright'] = 'Levende bokmerke Copyright';
$lang['feed_description'] = 'Levende bokmerke beskrivelse';
$lang['feed_editor'] = 'Levende bokmerke Redigerer';
$lang['feed_extension'] = 'Levende bokmerke endelse';
$lang['feed_image'] = 'Levende bokmerke Bilde';
$lang['feed_link'] = 'Levende bokmerke Lenke';
$lang['feed_namealias'] = 'Levende bokmerke Navn/Alias';
$lang['feed_pageid'] = 'Benytt denne siden for lenker';
$lang['feed_title'] = 'Levende bokmerke Tittel';
$lang['feed_ttl'] = 'Tid &aring; v&aelig;re aktiv';
$lang['friendlyname'] = 'Calguys Feed Maker ';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module provides the ability to build and manage RSS Feeds consisting of data from any CMS Made Simple module that supports a summary view.</p>
<p>It supports categorizing the feeds, generating auto-discovery links, and standalone links to rss feeds.</p>
<p>Pretty URL&#039;s are supported if your site has them enabled. - <em>ex:</em> http://www.yoursite.com/feeds/Feed-Name</p>
<h3>How Do I Use It?</h3>
<ul>
<li>-First you must create a new feed, and fill in the parameters supplied.
  <p>A template is associated with each feed.  The default template illustrates how to generate an RSS feed from the News module</p>
  <p>To generate templates from other feeds you will need to use the template variables from that module. Put {get_template_vars} in a page that uses that module to see which variables you can call into your Feed Template. To control the output of your feed you need to use a combination of these template variables and modify your module call in the template.</p>
</li>
<li>-Secondly you should place an auto-discovery tag in the appropriate place.
  <p>This will create auto-discovery links in your output.  You can place this tag in the head section of the page template, or the metadata section of specific pages to generate autodiscovery.  Various parameters can be specified to control which feeds auto-discovery links are generated for.<br /></p>
<p>  
<em>ex1:</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; feed=&#039;myFeed1,myFeed2 &#039;}</strong> - This creates autodiscovery links for all specified feeds<br />
<em>ex2:</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; category=&#039;myCategory1,myCategory2&#039;}</strong> - This creates autodiscovery links for all feeds in the specified category or categories</p>
</li>
  <li>-Thirdly, you can place links to specific feeds in your content.  using the action=rsslink parameter.<p>This will create a link to the specified feed in the location you put the call.</p>
  <p><em>ex1:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039;}</strong> - Generic &quot;rsslink&quot; call
  <br/>
  <em>ex2:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; imageonly=&#039;&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039;}</strong> - This call displays a link that shows only an Image for the link, it specifies a different image that was uploaded to use for the link than the default image and it uses a different CSS class to format the image (specified in one of your stylesheets)  
  <br />
   <em>ex3:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; text=&#039;RSS News Feed&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039; linkclass=&quot;rssLink&quot;}</strong> - This call specifies different text for the link to the feed, specifies a new image to be used and uses different CSS classes to format the Image and Link (specified in one of your stylesheets)   </p> 
  </ul>
<h3>Notes:</h3>
<ul>
<li>This module will work best, and the default feeds will validate if you have configured pretty urls properly.   Otherwise, atom links seem to have problems with some of our URLS.</li>
</ul>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['info_alias'] = 'Dette levende mokmerket m&aring; kun inneholde tegn som er egnet for en lenke';
$lang['info_copyright'] = 'Kopirett notis for innhold i denne kanalen';
$lang['info_description'] = 'En frase eller setning som beskriver denne kanalen';
$lang['info_editor'] = 'Epostadresse til den som har ansvaret for redigering av denne kanalen';
$lang['info_extension'] = 'Str&oslash;m filendelse (spesifiser en filendelse for denne str&oslash;mmen, feks. xml,rss,kml... om dette ikke er spesifisert vil standard rss filendelse bli benyttet';
$lang['info_feed_extension'] = 'N&aring;r mod_rewrite benyttes for &aring; oppn&aring; vakre url&#039;er kan denne parameter benyttes for &aring; spesifisere filendelsen p&aring; de genererte levende bokmerkene.';
$lang['info_image'] = 'Spesifiserer en GIF, JPEG eller PNG bilde som kan vises sammen med kanalen';
$lang['info_link'] = 'Lenken til HTML nettsiden som korresponderer til kanalen';
$lang['info_pageid'] = 'Siden som skal benyttes for alle lenker i dette levende bokmerket';
$lang['info_ttl'] = 'antall minutter som indikerer hvor lenge en kanal kan mellomlagres f&oslash;r oppfrisking fra kilden';
$lang['moddescription'] = 'Et fleksibelt verkt&oslash;y for opprettelse og behandling av levende bokmerker(RSS feeds)';
$lang['name'] = 'Navn';
$lang['param_action'] = 'Spesifiserer oppf&oslash;rselen til modulen. Det er to mulige verdier for denne parameteren &quot;autodiscovery&quot; &amp; &quot;rsslink&quot;. autodiscovery handlingen vil generere auto discovery lenker, og b&oslash;r brukes der hvor det resulterende innholdet opptrer i hodeseksjonen av din visning. rsslink  handlingen kan benyttes for &aring; opprette en lenke til et spesifisert levende bokmerke, og kan plasseres i ditt sideinnhold';
$lang['param_category'] = 'Kan kun benyttes med autodiscovery handlingen, denne parameter tillater deg da &aring; spesifisere en kommaseparert liste med levende bokmerke kategorier som vil kontrollere hvilke str&oslash;mmer lenker blir generert for';
$lang['param_feed'] = 'Brukes i rsslink og autodiscovery handlingen. Denne parameter tillater deg &aring; spesifisere hvilke str&oslash;mmer det skal genereres lenke for. S&aring; i autodiscovery handlingen, kan en kommaseparert liste med navn p&aring; str&oslash;mmer oppgis.';
$lang['param_image'] = 'Nyttig i rsslink handlingen - denne parameteren tillater deg &aring; spesifisere et annet bilde for levende bokmerke lenken';
$lang['param_imageclass'] = 'Spesifiser en CSS klasse som skal sendes i bilde taggen for et levende bokmerke lenke';
$lang['param_imageonly'] = 'Nyttig i rsslink handlingen - denne parameter tillater deg &aring; spesifisere at ingen tekst skal vises med lenken';
$lang['param_linkclass'] = 'Spesifiser en CSS klasse som skal sendes i lenke taggen for et levende bokmerke lenke';
$lang['param_urlonly'] = 'Kun gyldig for rsslink handlingen, denne parameteren krever at koden kun viser URL til RSS-str&oslash;mmen';
$lang['param_text'] = 'Nyttig i rsslink handlingen - denne parameter tillater deg &aring; spesifisere teksten som skal assosieres med lenken. Om denne parameter ikke er satt vil tittelen for det levende bokmerket benyttes';
$lang['postinstall'] = 'CGFeedMaker modulen ble vellykket installert';
$lang['postuninstall'] = 'CGFeedMaker modulen, og alle assosierte data har blitt fjernet';
$lang['really_uninstall'] = 'Er du sikker p&aring; at du vil fjerne denne modulen? All data assosiert med denne modulen vil bli fjernet';
$lang['reset_to_factory'] = 'Tilbakestill til fabrikkstandard';
$lang['settings'] = 'Innstillinger';
$lang['submit'] = 'Utf&oslash;r';
$lang['template'] = 'Mal';
$lang['template_source'] = 'Malkilde';
$lang['utmz'] = '156861353.1274726983.2794.62.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/bug/view/4955';
$lang['utma'] = '156861353.179052623084110100.1210423577.1275684826.1275690246.2838';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> CGFeedMaker-1.0.19.tar.gz: CGFeedMaker/lang/ext/nb_NO.php <==
<?php
$lang['addcategory'] = 'Legg til en ny kategori';
$lang['addedit_feed'] = 'Legg til/rediger levende bokmerke';
$lang['addfeed'] = 'Legg til nytt levende bokmerker';
$lang['areyousure_delete'] = 'Er du sikker p&aring; at du vil slette denne enheten?';
$lang['cancel'] = 'Avbryt';
$lang['categories'] = 'Kategorier';
$lang['current_value'] = 'N&aring;v&aelig;rende verdi';
$lang['delete'] = 'Slett';
$lang['details'] = 'Detaljer';
$lang['edit'] = 'Rediger';
$lang['error_missingparam'] = 'En p&aring;krevd parameter eller verdi ble ikke funnet';
$lang['error_nameexists'] = 'En enhet med det navnet eksisterer allerede';
$lang['error_nocatname'] = 'Vennligst spesifiser et kategorinavn';
$lang['error_nonamegiven'] = 'Du m&aring; oppgi et navn/alias';
$lang['error_nopermission'] = 'Tilgang nektet';
$lang['error_notemplate'] = 'Ingen mal oppgitt';
$lang['feeds'] = 'Levende bokmerker';
$lang['feed_copyright'] = 'Levende bokmerke Copyright';
$lang['feed_description'] = 'Levende bokmerke beskrivelse';
$lang['feed_editor'] = 'Levende bokmerke Redigerer';
$lang['feed_extension'] = 'Levende bokmerke endelse';
$lang['feed_image'] = 'Levende bokmerke Bilde';
$lang['feed_link'] = 'Levende bokmerke Lenke';
$lang['feed_namealias'] = 'Levende bokmerke Navn/Alias';
$lang['feed_pageid'] = 'Benytt denne siden for lenker';
$lang['feed_title'] = 'Levende bokmerke Tittel';
$lang['feed_ttl'] = 'Tid &aring; v&aelig;re aktiv';
$lang['feed_url'] = 'Levende bokmerker URL';
$lang['friendlyname'] = 'Calguys Feed Maker ';
$lang['info_alias'] = 'Dette levende mokmerket m&aring; kun inneholde tegn som er egnet for en lenke';
$lang['info_copyright'] = 'Kopirett notis for innhold i denne kanalen';
$lang['info_description'] = 'En frase eller setning som beskriver denne kanalen';
$lang['info_editor'] = 'Epostadresse til den som har ansvaret for redigering av denne kanalen';
$lang['info_extension'] = 'Str&oslash;m filendelse (spesifiser en filendelse for denne str&oslash;mmen, feks. xml,rss,kml... om dette ikke er spesifisert vil standard rss filendelse bli benyttet';
$lang['info_feed_extension'] = 'N&aring;r mod_rewrite benyttes for &aring; oppn&aring; vakre url&#039;er kan denne parameter benyttes for &aring; spesifisere filendelsen p&aring; de genererte levende bokmerkene.';
$lang['info_image'] = 'Spesifiserer en GIF, JPEG eller PNG bilde som kan vises sammen med kanalen';
$lang['info_link'] = 'Lenken til HTML nettsiden som korresponderer til kanalen';
$lang['info_pageid'] = 'Siden som skal benyttes for alle lenker i dette levende bokmerket';
$lang['info_ttl'] = 'antall minutter som indikerer hvor lenge en kanal kan mellomlagres f&oslash;r oppfrisking fra kilden';
$lang['moddescription'] = 'Et fleksibelt verkt&oslash;y for opprettelse og behandling av levende bokmerker(RSS feeds)';
$lang['name'] = 'Navn';
$lang['param_action'] = 'Spesifiserer oppf&oslash;rselen til modulen. Det er to mulige verdier for denne parameteren &quot;autodiscovery&quot; &amp; &quot;rsslink&quot;. autodiscovery handlingen vil generere auto discovery lenker, og b&oslash;r brukes der hvor det resulterende innholdet opptrer i hodeseksjonen av din visning. rsslink  handlingen kan benyttes for &aring; opprette en lenke til et spesifisert levende bokmerke, og kan plasseres i ditt sideinnhold';
$lang['param_category'] = 'Kan kun benyttes med autodiscovery handlingen, denne parameter tillater deg da &aring; spesifisere en kommaseparert liste med levende bokmerke kategorier som vil kontrollere hvilke str&oslash;mmer lenker blir generert for';
$lang['param_feed'] = 'Brukes i rsslink og autodiscovery handlingen. Denne parameter tillater deg &aring; spesifisere hvilke str&oslash;mmer det skal genereres lenke for. S&aring; i autodiscovery handlingen, kan en kommaseparert liste med navn p&aring; str&oslash;mmer oppgis.';
$lang['param_image'] = 'Nyttig i rsslink handlingen - denne parameteren tillater deg &aring; spesifisere et annet bilde for levende bokmerke lenken';
$lang['param_imageclass'] = 'Spesifiser en CSS klasse som skal sendes i bilde taggen for et levende bokmerke lenke';
$lang['param_imageonly'] = 'Nyttig i rsslink handlingen - denne parameter tillater deg &aring; spesifisere at ingen tekst skal vises med lenken';
$lang['param_linkclass'] = 'Spesifiser en CSS klasse som skal sendes i lenke taggen for et levende bokmerke lenke';
$lang['param_urlonly'] = 'Kun gyldig for rsslink handlingen, denne parameteren krever at koden kun viser URL til RSS-str&oslash;mmen';
$lang['param_text'] = 'Nyttig i rsslink handlingen - denne parameter tillater deg &aring; spesifisere teksten som skal assosieres med lenken. Om denne parameter ikke er satt vil tittelen for det levende bokmerket benyttes';
$lang['postinstall'] = 'CGFeedMaker modulen ble vellykket installert';
$lang['postuninstall'] = 'CGFeedMaker modulen, og alle assosierte data har blitt fjernet';
$lang['really_uninstall'] = 'Er du sikker p&aring; at du vil fjerne denne modulen? All data assosiert med denne modulen vil bli fjernet';
$lang['reset_to_factory'] = 'Tilbakestill til fabrikkstandard';
$lang['settings'] = 'Innstillinger';
$lang['submit'] = 'Utf&oslash;r';
$lang['template'] = 'Mal';
$lang['template_source'] = 'Malkilde';
$lang['utma'] = '156861353.787464702.1355990775.1357824154.1357827788.5';
$lang['utmz'] = '156861353.1355990775.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['qca'] = 'P0-1783067311-1323366114110';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
